@@ -9,19 +9,20 @@
 #include <memory>
 #include <vector>
 
-class QQuickWebEngineDownloadItem;
+class QQuickWebEngineDownloadRequest;
+using DownloadItem = QQuickWebEngineDownloadRequest;
 
 class DownloadManager
 {
 public:
     static DownloadManager &instance();
 
-    Q_INVOKABLE void addDownload(std::unique_ptr<QQuickWebEngineDownloadItem> &&download);
+    Q_INVOKABLE void addDownload(std::unique_ptr<DownloadItem> &&download);
     Q_INVOKABLE void removeDownload(const int index);
-    const std::vector<std::unique_ptr<QQuickWebEngineDownloadItem>> &downloads();
+    const std::vector<std::unique_ptr<DownloadItem>> &downloads();
 
 private:
     DownloadManager();
 
-    std::vector<std::unique_ptr<QQuickWebEngineDownloadItem>> m_downloads;
+    std::vector<std::unique_ptr<DownloadItem>> m_downloads;
 };
